#Tableau périodique

import matplotlib.pyplot as plt
import matplotlib.patches as mpatches
from matplotlib import colors as mcolors#pour la fonction to_rgba() : rectangles avec alpha différent de 1
import pandas as pd

#%%%%%%%%%%%%%%%%%%%%%%%%%%%
a=6#espace horizontal
b=6#espace vertical

blocs=True#afficher les limites des blocs
familles=False#afficher les limites des familles

#%%%%%%%%%%%%%%%%%%%%%%%%%%%

#extraction des données :
table=pd.read_csv("periodic-table.csv", 
delimiter=";", 
skiprows=2, #ne lit pas les deux premières lignes
#nrows=18,#permet de limiter à quelques périodes. Mais adapter les dimensions
usecols=[0, 1, 2, 3, 4, 6], #sélectionne les colonnes utiles
names=['numéro atomique', "symbole", 'nom', 'ligne', 'colonne','masse atomique'], #renommer les colonnes
)
Z=table["numéro atomique"]
nom=table["nom"]
symb=table["symbole"]
ligne=table["ligne"]
colonne=table["colonne"]
masses=table["masse atomique"]

#---------------------------------------------------------

def chiffSignif(n):#3 chiffres significatifs
    n=n.replace('(','').replace(')','')
    n=float(n)
    if n<10:
        valeur='{:.2f}'.format(n)
    elif n<100:
        valeur= '{:.1f}'.format(n)
    else:
        valeur= '{:.0f}'.format(n)
    return valeur.replace('.',',')#virgule à la place du point

#---------------------------------------------------------
plt.rcParams["font.family"] = "Roboto"#ou autre police installée

#paramètres du graphique
fig, ax=plt.subplots(figsize=(29.7/2.54,21/2.54), 
tight_layout=True, #marges réduites
facecolor='cornflowerblue',
)
#ax.set_aspect('equal')
plt.title("Le tableau périodique des éléments chimiques", y=0.88,fontsize=18,bbox=dict(boxstyle='round',facecolor='orange'))
plt.xticks([])
plt.yticks([])
#plt.axis('off')#retire le cadre du graphe
plt.xlim(0, 19*a)#à adapter aux dimensions choisies pour la figure
plt.ylim(-11*b, 0)# à adapter au nombre de périodes représentées

#tracé des cases :
for i in range(len(table)):
    # if int(Z[i])<57 or int(Z[i])>71:#supprime les lanthanides
    #     if int(Z[i])<89 or int(Z[i])>103:#supprime les actinides
    plt.text(a*colonne[i], -b/2-b*ligne[i], symb[i], fontsize=14, va='bottom', ha='center')#symbole
    plt.text(a*colonne[i]-0.20*a, -b/2-b*(ligne[i]+0.0),int(Z[i]), fontsize=7, ha='right')#N° atomique
    plt.text(a*colonne[i], -b*(ligne[i]+0.05),nom[i], fontsize=6, ha='center')#nom
    plt.text(a*(colonne[i]+0.3), -b*(ligne[i]+0.75),chiffSignif(masses[i]), fontsize=6, ha='center',c='crimson')#masse atomique
    rectangle=mpatches.Rectangle((a*(colonne[i]-0.5),-b*(ligne[i])-5),a,b,facecolor='none',ec='k')
    ax.add_artist(rectangle)#cases

#n° des colonnes :-------------------------------
for i in range(1, 19):
    plt.text(a*(i-0.2), -3, "%s"%(i), fontsize=8)
#------------------------------------------------------------------------------------

#Les FAMILLES :----------------------------------------
if familles==True:
    coul18=mcolors.to_rgba('orange', 0.5)#le dernier paramètre est alpha (opacité de 0 à 1)
    #ici : tracer un rectangle qui encadre les gaz nobles
    rectangle=mpatches.Rectangle((a*17.5, -b*7.84), a, b*7, fc=coul18, zorder=0)
    ax.add_artist(rectangle)
    plt.text(a*4, -b*2, "gaz nobles", fontweight='bold', bbox=dict(facecolor=coul18))
    
    coul17=mcolors.to_rgba('gold', 0.5)
    #ici : tracer un rectangle qui encadre les halogènes
    rectangle=mpatches.Rectangle((a*16.5, -b*7.84), a, b*6, color=coul17, zorder=0)
    ax.add_artist(rectangle)
    plt.text(a*4, -b*2.5, "halogènes", fontweight='bold', bbox=dict(facecolor=coul17))
    
    coul1=mcolors.to_rgba('royalblue', 0.5)
    #ici : tracer un rectangle qui encadre les alcalins
    rectangle=mpatches.Rectangle((0.5*a, -b*7.84), a, b*7, color=coul1, zorder=0)
    ax.add_artist(rectangle)
    plt.text(a*4, -b*3, "alcalins", fontweight='bold', bbox=dict(facecolor=coul1))
    
    coul2=mcolors.to_rgba('yellowgreen', 0.5)
    #ici : tracer un rectangle qui encadre les alcalino-terreux
    rectangle=mpatches.Rectangle((1.5*a, -b*7.84), a, b*6, color=coul2, zorder=0)
    ax.add_artist(rectangle)
    plt.text(a*4, -b*3.5, "alcalino-terreux", fontweight='bold', bbox=dict(facecolor=coul2))

#-----------------------------------------------------------------------------------------


#LES BLOCS---------------------------------------------
if blocs==True:
    coulS=mcolors.to_rgba('orange', 0.5)#BLOC s
    rectangle=mpatches.Rectangle((a/2, -b*7.84), a, b*7, color=coulS,zorder=0)#alcalins
    ax.add_artist(rectangle)
    rectangle=mpatches.Rectangle((1.5*a, -b*7.84), a, b*6, color=coulS,zorder=0)#col2
    ax.add_artist(rectangle)
    rectangle=mpatches.Rectangle((17.5*a, -b*1.84), a, b, color=coulS,zorder=0)#He
    ax.add_artist(rectangle)
    plt.text(3*a, -b*3, "bloc s", fontweight='bold', bbox=dict(fc=coulS))
    
    coulP=mcolors.to_rgba('darkslateblue',0.5)#BLOC p
    rectangle=mpatches.Rectangle((12.5*a, -b*7.84), 6*a, b*6, color=coulP,zorder=0)
    ax.add_artist(rectangle)
    plt.text(5*a, -b*3, "bloc p", fontweight='bold', bbox=dict(fc=coulP))
    
    coulD=mcolors.to_rgba('greenyellow',0.5)#BLOC d
    rectangle=mpatches.Rectangle((2.5*a, -b*7.84), 10*a, b*4, color=coulD,zorder=0)
    ax.add_artist(rectangle)
    plt.text(7*a, -b*3, "bloc d", fontweight='bold', bbox=dict(fc=coulD))
    
    coulF=mcolors.to_rgba('thistle',0.5)#BLOC f
    rectangle=mpatches.Rectangle((4.5*a, -b*10.84), 14*a, b*2, color=coulF,zorder=0)
    ax.add_artist(rectangle)
    plt.text(9*a, -b*3, "bloc f", fontweight='bold', bbox=dict(fc=coulF))

#-----------------------------------------------------------------------------------------
#Traits d'insertion du bloc f:
plt.plot([3.5*a,4.4*a],[-7.84*b,-8.84*b],c='k',lw=1)
plt.plot([3.5*a,4.4*a],[-7.84*b,-10.84*b],c='k',lw=1)
#-----------------------------------------------------------------------------------------
if blocs==True:
    NomFichier='TableauPerBlocs'
elif familles==True:
    NomFichier='TableauPerFamilles'
else: NomFichier='TableauPerSimple'
fig.savefig(NomFichier)
fig.savefig(NomFichier+'.png', dpi=400)
fig.savefig(NomFichier+'.pdf')

#plt.show()
